# 🤘 Lemmy3

Lemmy3 is an experimental fork of [Lemmy](https://github.com/sorenlind/lemmy)

It has been refactored in object-oriented manner, the codebase is extended with type-hints and spacy-compatible serialization, and a simple frequency-based disambiguation method is added. The tool comes with a command line interface (`lemmy`) for training lemmatizer models.